@@ -1,7 +1,9 @@
 from yafowil.base import factory
 from .connectors import plone_preprocessor
 
+
 def register():
     factory.register_global_preprocessors([plone_preprocessor])  
-    factory.defaults['form.class'] = 'edit-form enableUnloadProtection enableAutoFocus'    
+    factory.defaults['form.class'] = \
+        'edit-form enableUnloadProtection enableAutoFocus'    
     factory.defaults['label.class'] = "formQuestion"
\ No newline at end of file
